==> amplify_auth_plugin_interface-0.1.4.tar.gz: lib/src/Exceptions/ResourceNotFoundException.dart <==
/*
 * Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

import 'package:amplify_auth_plugin_interface/amplify_auth_plugin_interface.dart';

/// Thrown when the requested resource does not exist.
class ResourceNotFoundException extends AuthException {
  /// Named constructor
  ResourceNotFoundException(String message,
      {String recoverySuggestion, String underlyingException})
      : super(message,
            recoverySuggestion: recoverySuggestion,
            underlyingException: underlyingException);

  /// Constructor for down casting an AuthException to this exception
  ResourceNotFoundException._private(AuthException exception)
      : super(exception.message,
            recoverySuggestion: exception.recoverySuggestion,
            underlyingException: exception.underlyingException);

  /// Instantiates and return a new `AuthException` from the
  /// serialized exception data
  static ResourceNotFoundException fromMap(
      Map<String, String> serializedException) {
    return ResourceNotFoundException._private(
        AuthException.fromMap(serializedException));
  }
}

==> amplify_auth_plugin_interface-0.5.1.tar.gz: lib/src/Exceptions/ResourceNotFoundException.dart <==
/*
 * Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

import 'package:amplify_auth_plugin_interface/amplify_auth_plugin_interface.dart';

/// {@template auth.resource_not_found_exception}
/// Exception thrown when the requested resource doesn't exist.
/// {@endtemplate}
class ResourceNotFoundException extends AuthException {
  /// {@macro auth.resource_not_found_exception}
  ResourceNotFoundException(String message,
      {String? recoverySuggestion, String? underlyingException})
      : super(message,
            recoverySuggestion: recoverySuggestion,
            underlyingException: underlyingException);

  /// {@macro auth.exception_downcasting}
  ResourceNotFoundException._private(AuthException exception)
      : super(exception.message,
            recoverySuggestion: exception.recoverySuggestion,
            underlyingException: exception.underlyingException);

  /// {@macro auth.exception_from_map}
  static ResourceNotFoundException fromMap(
      Map<String, String> serializedException) {
    return ResourceNotFoundException._private(
        AuthException.fromMap(serializedException));
  }
}
